# Sitemap

`sitemap.xml` is a standard for search engines to find content on your site. `coltrane` automatically provides a URL route for `sitemap.xml` and will create the file when building a static site.

## Django app configuration

When using `coltrane` as a `Django` app, the sitemap will [need to be configured](django-app/integration.md#sitemap).
